package com.mints.goodmoney.ad.tz_ad;

import androidx.annotation.Nullable;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.manager.UserManager;
import com.tz.sdk.coral.ad.CoralAD;
import com.tz.sdk.coral.callback.CoralADListener;
import com.tz.sdk.coral.callback.h5.DownloadProcess;
import com.tz.sdk.coral.task.RewardTask;
import com.tz.sdk.core.ad.ADError;
import com.tz.sdk.core.ad.ADSource;
import com.tz.sdk.core.ad.ADType;
import com.tz.sdk.core.loader.ADLoader;

import java.util.HashMap;
import java.util.List;

/**
 * 下载
 */
public final class CoralDownload {

    public static final int RELEASE_TASK_TYPE = 103;

    private int mTaskType;

    /**
     *
     * taskType 珊瑚的任务类型 103正式环境 134测试环境
     */
    public CoralDownload(int taskType) {
        mTaskType = taskType;
    }

//    public boolean i = true;

    /**
     * i用于判断如果已经在下载了，那就在download回调里return false，不进行重复的下载
     *
     * @return
     */
//    public com.mints.goodmoney.ad.tz_ad.ADType getADType() {
//        return com.mints.goodmoney.ad.tz_ad.ADType.CoralDownload;
//    }
    public void pull() {
        new ADLoader(MintsApplication.getContext())
                .get(ADType.APP_DOWNLOAD)
                .from(ADSource.CORAL)
                .count(1)
                .reward(true)
                .with(new HashMap<String, Object>() {
                    {
                        put(CoralAD.Key.TASK_TYPE, mTaskType);
                        put(CoralAD.Key.ACCOUNT_ID, UserManager.getInstance().getUserID());
                        put(CoralAD.Key.LOGIN_KEY, UserManager.getInstance().getTokenID());
                    }
                })
                .load(new CoralADListener() {
                    @Override
                    public boolean onTaskAvailable(RewardTask rewardTask) {
                        return super.onTaskAvailable(rewardTask);
                    }

                    @Override
                    public boolean onTaskNotAvailable(int taskType, ADError adError) {
                        return super.onTaskNotAvailable(taskType, adError);
                    }

                    @Override
                    public boolean openH5(CoralAD ad, String h5Url) {
                        return super.openH5(ad, h5Url);
                    }

                    @Override
                    public boolean download(DownloadProcess downloadProcess) {
//                        if (!i) {
//                            return false;
//                        }
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onGetDownloadProcess(downloadProcess);
                        }

//                        downloadProcess.reportDownloadStart();
                        return false;
                    }

                    @Override
                    public void onAdFailed(ADError adError) {
                        super.onAdFailed(adError);
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onLoadFail();
                        }
                    }

                    @Override
                    public void onAdLoaded(List<CoralAD> adList) {
                        if (adList != null && adList.size() > 0) {
                            if (mOnAdLoadListener != null) {
                                mOnAdLoadListener.onLoadSuccess(adList);
                            }
                        } else {
                            if (mOnAdLoadListener != null) {
                                mOnAdLoadListener.onLoadFail();
                            }
                        }
                    }

                    @Override
                    public boolean onAdShow(@Nullable CoralAD ad) {
                        return false;
                    }

                    @Override
                    public boolean onAdClicked(@Nullable CoralAD ad) {
                        return false;
                    }

                    @Override
                    public boolean onAppDownloading(@Nullable CoralAD ad, @Nullable String downloadUrl) {
//                        i = false;
                        return false;
                    }

                    @Override
                    public boolean onAppDownloaded(@Nullable CoralAD ad, @Nullable String downloadUrl, @Nullable String localFile) {
//                        i = true;
                        return false;
                    }

                    @Override
                    public boolean onAppInstalled(@Nullable CoralAD ad, @Nullable String downloadUrl, @Nullable String localFile) {
                        return false;
                    }

                    @Override
                    public boolean onAppActivated(CoralAD ad, String downloadUrl, String localFile) {
                        return super.onAppActivated(ad, downloadUrl, localFile);
                    }
                });
    }

    private OnAdLoadListener mOnAdLoadListener;

    public CoralDownload setOnAdLoadListener(OnAdLoadListener onAdLoadListener) {
        mOnAdLoadListener = onAdLoadListener;
        return this;
    }

    public void destroy() {
        mOnAdLoadListener = null;
    }

    public interface OnAdLoadListener {
        void onLoadSuccess(List<CoralAD> dataList);

        void onLoadFail();

        void onGetDownloadProcess(DownloadProcess downloadProcess);
    }
}
