package com.mints.goodmoney.ad.vedio

import android.app.Activity
import com.maplehaze.adsdk.video.RewardVideoAd
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.MhManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.mvp.presenters.MhVedioAdPresenter
import com.mints.goodmoney.mvp.views.VedioAdManagerView
import com.mints.goodmoney.utils.LogUtil

/**
 * 枫岚广告视频
 */
class MhVedioAdManager private constructor(activity: Activity) :
        BaseVedioAd(activity), VedioAdManagerView {

    private val TAG = MhVedioAdManager::class.java.simpleName

    private var mhVdedioAdPresenter: MhVedioAdPresenter? = null
    private var mhVedioAdListener: MhVedioAdListener? = null
    private var mRewardVideoAd: RewardVideoAd? = null

    private var isClickScreen: Boolean = true
    override var activity: Activity? = null

    companion object {
        private var _inst: MhVedioAdManager? = null
        fun getInstance(activity: Activity): MhVedioAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = MhVedioAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
        mhVdedioAdPresenter = MhVedioAdPresenter()
        mhVdedioAdPresenter?.attachView(this)
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        val postId: String = when (carrierType) {
            Constant.CARRIER_VERSUS_VIDEO -> MhManager.POS_ID
            Constant.CARRIER_HOMEWATER -> MhManager.POS_ID
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_DRAWCASH -> MhManager.POS_ID
            Constant.CARRIER_CHALLENGE_CARD -> MhManager.POS_ID
            else -> MhManager.POS_ID
        }

        val orientation = RewardVideoAd.VERTICAL

        mRewardVideoAd = RewardVideoAd(activity, MhManager.APP_ID, postId, orientation, object : RewardVideoAd.RewardVideoListener {
            override fun onADCached() {
                LogUtil.d(TAG, "onADCached")
                mRewardVideoAd?.showAd(activity)
            }

            override fun onADShow() {
                LogUtil.d(TAG, "onADShow")
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_ZERO, "", "")
            }

            override fun onReward() {
                LogUtil.d(TAG, "onReward")
            }

            override fun onADClick() {
                if (AppConfig.needReportClickAdEvent) {
                    TrackManager.getInstance().reportClickAdEvent()
                }

                LogUtil.d(TAG, "onADClick")
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_TWO, "", "")
                if (isClickScreen) {
                    // 防止重复
                    TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_FOUR, "", "")
                    isClickScreen = false
                }
                if (mhVedioAdListener != null) {
                    mhVedioAdListener?.mhVedioAdDownload()
                }
            }

            override fun onVideoComplete() {
                LogUtil.d(TAG, "onVideoComplete")
            }

            override fun onADClose() {
                LogUtil.d(TAG, "onADClose")

                mhVdedioAdPresenter?.reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_FL, extraId, curCoin))

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_THREE, "", "")

                if (mhVedioAdListener != null) {
                    mhVedioAdListener?.mhVedioAdSuccess()
                }
            }

            override fun onADError(p0: Int) {
                LogUtil.d(TAG, "onADError->$p0")

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_FL, Constant.EVENT_TYPE_ONE, (p0).toString(), "")

                if (mhVedioAdListener != null) {
                    mhVedioAdListener?.mhVedioAdFail()
                }
            }

        })

        mRewardVideoAd?.loadAd()
    }

    fun setMhVedioAdListener(mhVedioAdListener: MhVedioAdListener?) {
        this.mhVedioAdListener = mhVedioAdListener
    }

    interface MhVedioAdListener {
        fun mhVedioAdSuccess()
        fun mhVedioAdFail()
        fun mhVedioAdDownload()
    }

    override fun onDestory() {
        mhVdedioAdPresenter?.let {
            it.dispose()
            it.detachView()
        }

        mRewardVideoAd = null
        activity = null
    }
}