package com.mints.goodmoney.ad.vedio;

import android.app.Activity;
import android.text.TextUtils;

import com.mints.goodmoney.common.AppConfig;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.mvp.model.VedioAdingBean;
import com.mints.goodmoney.mvp.model.WeightBean;
import com.mints.goodmoney.utils.LogUtil;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Random;

/**
 * 视频广告播放
 */
public class VedioAdingManager {

    private static final String TAG = VedioAdingManager.class.getSimpleName();

    private static VedioAdingManager _inst;

    private VedioAdingListener vedioAdingListener;

    private WnVedioAdManager wnVedioAdManager;
    private CsjVedioAdManager csjVedioAdManager;
    private YlhVedioAdManager ylhVedioAdManager;
    private MhVedioAdManager mhVedioAdManager;

    private int wnWeight;
    private int ylhWeight;
    private int csjVedioWeight;
    private int flVedioWeight;
    private ArrayList<WeightBean> weightList;

    // 是否是高额视频任务
    private boolean isHighWeight = false;
    private boolean isTTVideoAd = false;

    private Activity activity;
    private boolean isVedioAdDownload = false;// 是否点击广告下载 true-点击

    public static VedioAdingManager getInstance(Activity activity) {
        if (_inst == null) {
            WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
            _inst = new VedioAdingManager(activityWeakReference.get());
        }
        return _inst;
    }

    private VedioAdingManager(Activity activity) {
        init(activity);
    }

    /**
     * 初始化广告manager
     *
     * @param activity
     */
    private void init(Activity activity) {
        this.activity = activity;
        csjVedioAdManager = CsjVedioAdManager.getInstance(activity);
        ylhVedioAdManager = YlhVedioAdManager.getInstance(activity);
        wnVedioAdManager = WnVedioAdManager.Companion.getInstance(activity);
        mhVedioAdManager = MhVedioAdManager.Companion.getInstance(activity);
        weightList = new ArrayList<>();
    }

    /**
     * 初始化广告权重
     */
    public void initAdWeight(int csjVedioWeight, int ylhWeight, int wnWeight, int flVedioWeight) {
        this.csjVedioWeight = csjVedioWeight;
        this.ylhWeight = ylhWeight;
        this.wnWeight = wnWeight;
        this.flVedioWeight = flVedioWeight;
    }

    /**
     * 根据类型加载对应视频(第一次加载)
     *
     * @param bean
     */
    public void loadAding(Activity activity, VedioAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();
        isVedioAdDownload = false;

        if (AppConfig.flVideoFlag) {
            // 先展示枫岚视频
            firstLoadFlVideo(bean);
        } else {
            // 权重自有逻辑
            loadAdVedio(getVedioAdType(), bean);
        }
    }

    /**
     * 根据载体优先加载枫岚
     *
     * @param bean
     */
    private void firstLoadFlVideo(VedioAdingBean bean) {
        String adType;
        switch (bean.getCarrierType()) {
            case Constant.CARRIER_VERSUS_VIDEO:
            case Constant.CARRIER_HOMEWATER:
            case Constant.CARRIER_WALK:
            case Constant.CARRIER_WALK_BUBBLE:
            case Constant.CARRIER_SIGNIN_HOMEPAGE_CARD:
            case Constant.CARRIER_OFFLINE_DOUBLE:
            case Constant.CARRIER_EATMEAL_SUBSIDY:
                adType = Constant.FL_VEDIO_AD;
//                ToastUtil.showLong(activity, "载体优先类型：" + Constant.FL_VEDIO_AD);
                break;
            default:
                adType = getVedioAdType();
                break;
        }
        loadAdVedio(adType, bean);
    }

    /**
     * 加载失败优先级对应视频
     *
     * @param bean
     */
    public void loadFailAding(Activity activity, VedioAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();

        isVedioAdDownload = false;
        loadAdVedio(getNextAdType(), bean);
    }

    /**
     * 根据广告优先级获取下一个
     */
    private String getNextAdType() {
        String nextAdType = "";
        if (AppConfig.csjVedioAdCount > 0) {
            nextAdType = Constant.CSJ_VEDIO_AD;
        } else if (AppConfig.ylhAdCount > 0) {
            nextAdType = Constant.YLH_VEDIO_AD;
        } else {
            nextAdType = Constant.FL_VEDIO_AD;
        }
        return nextAdType;
    }

    /**
     * 获取广告类型配置
     */
    private String getVedioAdType() {
        // 根据权重获取广告类型
        String adType;
        if (isHighWeight) {
            adType = getHighWeight();
        } else {
            adType = getRandomWeight();
        }
        isHighWeight = false;

        LogUtil.d(TAG, "权重结果返回的广告类型：" + adType);
        return adType;
    }

    public void setIsHighWeight(boolean isHighWeight) {
        this.isHighWeight = isHighWeight;
    }

    /**
     * 高额任务广告类型
     *
     * @return
     */
    private String getHighWeight() {
        isTTVideoAd = !isTTVideoAd;
        if (isTTVideoAd) {
            return Constant.CSJ_VEDIO_AD;
        } else {
            return Constant.YLH_VEDIO_AD;
        }
    }

    /**
     * 根据权重获取广告类型
     *
     * @return
     */
    private String getRandomWeight() {
        if (weightList != null) {
            weightList.clear();
        }
        int weight = 0;
        // 若没有视频完成数，不加入权重计算范围内
        if (AppConfig.csjVedioAdCount > 0) {
            weightList.add(new WeightBean(csjVedioWeight, Constant.CSJ_VEDIO_AD));
            weight = weight + csjVedioWeight;
            LogUtil.d(TAG, "权重值：csjVedioWeight:" + csjVedioWeight);
        }
        if (AppConfig.ylhAdCount > 0) {
            weightList.add(new WeightBean(ylhWeight, Constant.YLH_VEDIO_AD));
            weight = weight + ylhWeight;
            LogUtil.d(TAG, "权重值：ylhWeight:" + ylhWeight);
        }
        if (AppConfig.flVedioAdCount > 0) {
            weightList.add(new WeightBean(flVedioWeight, Constant.FL_VEDIO_AD));
            weight = weight + flVedioWeight;
            LogUtil.d(TAG, "权重值：flVedioWeight:" + flVedioWeight);
        }
        if (AppConfig.wnVedioAdCount > 0) {
            weightList.add(new WeightBean(wnWeight, Constant.SDHZ_VEDIO_AD));
            weight = weight + wnWeight;
            LogUtil.d(TAG, "权重值：sdhzWeight:" + wnWeight);
        }

        // 权重随机
        if (weightList != null && weightList.size() > 0 && weight > 0) {
            LogUtil.d(TAG, "1、权重总值：" + weight);
            Random r = new Random();
            int randomWeight = r.nextInt(weight) + 1;
            LogUtil.d(TAG, "2、权重随机值：" + randomWeight);

            for (WeightBean weightBean : weightList) {
                randomWeight -= weightBean.getWeight();
                if (randomWeight <= 0) {
                    LogUtil.d(TAG, "3、权重结果：" + weightBean.getType());
                    return weightBean.getType();
                }
            }
        }
        return "";
    }

    /**
     * 是否点击下载
     *
     * @return
     */
    public boolean isVedioAdDownload() {
        return this.isVedioAdDownload;
    }

    /**
     * 获取所有视频完成数状态  true-无可看视频
     *
     * @return
     */
    public boolean getVedioFinishFlag() {
        int csjVedioAdCount = AppConfig.csjVedioAdCount;
        int ylhAdCount = AppConfig.ylhAdCount;
        int wnAdCount = AppConfig.wnVedioAdCount;
        int flVedioAdCount = AppConfig.flVedioAdCount;

        if (ylhAdCount <= 0 && csjVedioAdCount <= 0 && wnAdCount <= 0 && flVedioAdCount <= 0) {
//            showToast("今日视频已看完，请明天再来吧");
            return true;
        }
        return false;
    }

    /**
     * 释放资源
     */
    public void onDestory() {
        if (csjVedioAdManager != null) {
            csjVedioAdManager.setCsjVedioAdListener(null);
            csjVedioAdManager.onDestory();
            csjVedioAdManager = null;
        }
        if (ylhVedioAdManager != null) {
            ylhVedioAdManager.setYlhVedioAdListener(null);
            ylhVedioAdManager.onDestory();
            ylhVedioAdManager = null;
        }
        if (wnVedioAdManager != null) {
            wnVedioAdManager.setWnVedioAdListener(null);
            wnVedioAdManager.onDestory();
            wnVedioAdManager = null;
        }
        if (mhVedioAdManager != null) {
            mhVedioAdManager.setMhVedioAdListener(null);
            mhVedioAdManager.onDestory();
            mhVedioAdManager = null;
        }

        activity = null;
    }

    public void setVedioAdingListener(VedioAdingListener vedioAdingListener) {
        this.vedioAdingListener = vedioAdingListener;
    }

    /**
     * 加载成功失败回调
     */
    public interface VedioAdingListener {
        void vedioAdingListenerError(String adType);

        void vedioAdingListenerFail(String adType);

        void vedioAdingListenerSuccess(String adType);
    }

    /**
     * 展示视频
     *
     * @param vedioAdType
     * @param bean
     */
    private void loadAdVedio(String vedioAdType, VedioAdingBean bean) {
        try {
            if (TextUtils.equals(vedioAdType, Constant.YLH_VEDIO_AD)) {
                // 优量汇
                if (ylhVedioAdManager == null) {
                    if (activity == null) {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerError(Constant.YLH_VEDIO_AD);
                        }
                        return;
                    }
                    ylhVedioAdManager = YlhVedioAdManager.getInstance(activity);
                }

                ylhVedioAdManager.setYlhVedioAdListener(new YlhVedioAdManager.YlhVedioAdListener() {
                    @Override
                    public void ylhVedioAdFail() {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerFail(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void ylhVedioAdSuccess() {
                        AppConfig.ylhAdCount--;
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerSuccess(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void ylhVedioAdDownload() {
                        isVedioAdDownload = true;
                    }
                });
                ylhVedioAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(vedioAdType, Constant.CSJ_VEDIO_AD)) {
                // 穿山甲激励视频
                if (csjVedioAdManager == null) {
                    if (activity == null) {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerError(Constant.CSJ_VEDIO_AD);
                        }
                        return;
                    }
                    csjVedioAdManager = CsjVedioAdManager.getInstance(activity);
                }


                csjVedioAdManager.setCsjVedioAdListener(new CsjVedioAdManager.CsjVedioAdListener() {
                    @Override
                    public void csjVedioAdFail() {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerFail(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void csjVedioAdSuccess() {
                        AppConfig.csjVedioAdCount--;
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerSuccess(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void csjVedioDownload() {
                        isVedioAdDownload = true;
                    }
                });
                csjVedioAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(vedioAdType, Constant.SDHZ_VEDIO_AD)) {
                // 闪电盒子激励视频
                if (wnVedioAdManager == null) {
                    if (activity == null) {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerError(Constant.SDHZ_VEDIO_AD);
                        }
                        return;
                    }
                    wnVedioAdManager = WnVedioAdManager.Companion.getInstance(activity);
                }
                wnVedioAdManager.setWnVedioAdListener(new WnVedioAdManager.WnVedioAdListener() {
                    @Override
                    public void wnVedioAdSuccess() {
                        AppConfig.wnVedioAdCount--;
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerSuccess(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void wnVedioAdFail() {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerFail(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void wnVedioAdDownload() {
                        isVedioAdDownload = true;
                    }
                });
                wnVedioAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(vedioAdType, Constant.FL_VEDIO_AD)) {
                // 枫岚广告激励视频
                if (mhVedioAdManager == null) {
                    if (activity == null) {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerError(Constant.FL_VEDIO_AD);
                        }
                        return;
                    }
                    mhVedioAdManager = MhVedioAdManager.Companion.getInstance(activity);
                }
                mhVedioAdManager.setMhVedioAdListener(new MhVedioAdManager.MhVedioAdListener() {
                    @Override
                    public void mhVedioAdSuccess() {
                        AppConfig.flVedioAdCount--;
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerSuccess(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void mhVedioAdFail() {
                        if (vedioAdingListener != null) {
                            vedioAdingListener.vedioAdingListenerFail(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void mhVedioAdDownload() {
                        isVedioAdDownload = true;
                    }
                });

                mhVedioAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (vedioAdingListener != null) {
                vedioAdingListener.vedioAdingListenerError(bean.getCarrierType());
            }
        }
    }

}