package com.mints.goodmoney.ad.vedio

import android.app.Activity
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.manager.WnManager
import com.mints.goodmoney.mvp.presenters.WnVedioAdPresenter
import com.mints.goodmoney.mvp.views.VedioAdManagerView
import com.mints.goodmoney.utils.LogUtil
import com.wannuosili.sdk.*

private val TAG = WnVedioAdManager::class.java.simpleName

/**
 * 闪电盒子视频
 */
class WnVedioAdManager private constructor(activity: Activity) :
        BaseVedioAd(activity), VedioAdManagerView {

    private var wnVedioAdPresenter: WnVedioAdPresenter? = null
    private var wnVedioAdListener: WnVedioAdListener? = null
    private var mRewardVideoAd: WNRewardVideoAd? = null

    private var isClickScreen: Boolean = true
    override var activity: Activity? = null

    companion object {
        private var _inst: WnVedioAdManager? = null
        fun getInstance(activity: Activity): WnVedioAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = WnVedioAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
        wnVedioAdPresenter = WnVedioAdPresenter()
        wnVedioAdPresenter?.attachView(this)
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        val postId: String = when (carrierType) {
            Constant.CARRIER_VERSUS_VIDEO -> WnManager.WN_AD_VEDIO_MAIN_POSTID
            Constant.CARRIER_HOMEWATER -> WnManager.WN_AD_VEDIO_DRINK_POSTID
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_DRAWCASH -> WnManager.WN_AD_VEDIO_TURNABLE_POSTID
            Constant.CARRIER_CHALLENGE_CARD -> WnManager.WN_AD_VEDIO_ERASE_POSTID
            else -> WnManager.WN_AD_VEDIO_MOREDIALOG_POSTID
        }
        val slot = WNAdSlot.Builder()
                .setSlotId(postId)
                .setOrientation(WNAdConstant.REWARD_VIDEO_AD_PORTRAIT)
                .build()

        WNAdSdk.getAdManager().loadRewardVideoAd(slot, object : WNRewardVideoAd.RewardVideoAdListener {
            override fun onError(code: Int, message: String) {
                LogUtil.d(TAG, "onError  $code:$message")

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SDHZ, Constant.EVENT_TYPE_ONE, (code).toString(), message)

                if (wnVedioAdListener != null) {
                    wnVedioAdListener?.wnVedioAdFail()
                }
            }

            override fun onLoad(ad: WNRewardVideoAd) {
                ad.interactionListener = object : WNRewardVideoAd.InteractionListener {
                    override fun onAdShow() {
                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SDHZ, Constant.EVENT_TYPE_ZERO, "", "")
                    }

                    override fun onAdClick() {
                        if (AppConfig.needReportClickAdEvent) {
                            TrackManager.getInstance().reportClickAdEvent()
                        }

                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SDHZ, Constant.EVENT_TYPE_TWO, "", "")

                        if (isClickScreen) {
                            // 防止重复
                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SDHZ, Constant.EVENT_TYPE_FOUR, "", "")
                            isClickScreen = false
                        }
                        if (wnVedioAdListener != null) {
                            wnVedioAdListener?.wnVedioAdDownload()
                        }
                    }

                    override fun onAdClose() {
                        wnVedioAdPresenter?.reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_SDHZ, extraId, curCoin))

                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_SDHZ, Constant.EVENT_TYPE_THREE, "", "")

                        if (wnVedioAdListener != null) {
                            wnVedioAdListener?.wnVedioAdSuccess()
                        }
                    }

                    override fun onVideoComplete() {
                    }

                    override fun onRewardVerify(rewardVerify: Boolean, rewardAmount: Int, rewardName: String) {
                    }
                }
                if (ad.type == WNAdConstant.AD_TYPE_DOWNLOAD) {
                    ad.downloadListener = object : WNAdDownloadListener {
                        override fun onDownloadStarted(totalBytes: Long, fileName: String, appName: String) {
                            showToast("开始下载")
                        }

                        override fun onDownloadFinished(totalBytes: Long, fileName: String, appName: String) {}

                        override fun onDownloadFailed(fileName: String, appName: String) {}
                    }
                }
                mRewardVideoAd = ad
                mRewardVideoAd?.showRewardVideoAd(activity)
            }
        })
    }

    fun setWnVedioAdListener(wnVedioAdListener: WnVedioAdListener?) {
        this.wnVedioAdListener = wnVedioAdListener
    }

    interface WnVedioAdListener {
        fun wnVedioAdSuccess()
        fun wnVedioAdFail()
        fun wnVedioAdDownload()
    }

    override fun onDestory() {
        wnVedioAdPresenter?.let {
            it.dispose()
            it.detachView()
        }

        mRewardVideoAd?.let {
            it.downloadListener = null
            it.interactionListener = null
        }
        mRewardVideoAd = null

        activity = null
    }
}