package com.mints.goodmoney.mvp.presenters

import android.text.TextUtils
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.manager.*
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.MainVedioMsgBean
import com.mints.goodmoney.mvp.model.UserBean
import com.mints.goodmoney.mvp.model.UserTaskMsgBean
import com.mints.goodmoney.mvp.views.HomeView
import com.mints.goodmoney.utils.DeviceUuidFactory
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable
import net.grandcentrix.tray.AppPreferences
import java.util.*

class HomePresenter : BasePresenter<HomeView>() {

    /**
     * 打开激活
     */
    fun comSaveTerminalInfo(ps: AppPreferences) {
        val vo = HashMap<String, Any>()
        val deviceInfo: DeviceInfo = DeviceInfo.instance
        val macAddress: String = deviceInfo.getMacAddress()
        val mac = macAddress.replace(":", "")
        vo["mac"] = mac
        vo["mac1"] = macAddress
        vo["androidid"] = deviceInfo.getAndroidId(null)
        vo["imei"] = deviceInfo.iMEI
        vo["oaid"] = MintsApplication.OAID
        vo["os"] = "android"
        vo["model"] = deviceInfo.newModel
        vo["uuid"] = DeviceUuidFactory().deviceUuid
        vo["osversion"] = deviceInfo.oSVersion
        vo["appversion"] = deviceInfo.versionName

        AppHttpManager.getInstance(loanApplication)
                .call(loanService.comSaveTerminalInfo(vo),
                        object : BaseSubscriber<BaseResponse<Any>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                            }

                            override fun onNext(baseResponse: BaseResponse<Any>) {
                                if (isLinkView) return
                                val code: Int = baseResponse.getStatus()
                                when (code) {
                                    200 -> {
//                                        ps.put(Constant.FIRST_DEVICE_FLAG, true)
                                    }
                                }
                            }
                        })
    }

    fun getHallBaseMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getHallBaseMsg(),
                        object : BaseSubscriber<BaseResponse<UserTaskMsgBean>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                                view.hideLoading()
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.hideLoading()
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<UserTaskMsgBean>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> view.getHallBaseMsgSuc(baseResponse.getData())
                                    else -> {
                                        view.showToast(message)
                                    }
                                }
                            }
                        })
    }

    fun getHomeVedioMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getHomeVedioMsg(),
                        object : BaseSubscriber<BaseResponse<MainVedioMsgBean>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                            }

                            override fun onNext(baseResponse: BaseResponse<MainVedioMsgBean>) {
                                if (isLinkView) return

                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> view.getHomeVedioMsgSuc(baseResponse.getData())
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    /**
     * 游客登录
     */
    fun userLogin() {
        val vo = HashMap<String, Any>()
        vo["shumeiId"] = ShumeiManager.getInstance().shumeiDeviceId
        vo["device"] = DeviceUuidFactory().deviceUuid.toString()
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.visitorlogin(vo),
                        object : BaseSubscriber<BaseResponse<UserBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                            }

                            override fun onNext(baseResponse: BaseResponse<UserBean>) {
                                if (isLinkView) return

                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                val data: UserBean? = baseResponse.getData()
                                when (code) {
                                    200 -> if (data != null) {
                                        UserManager.getInstance().saveUserInfo(data)
                                        saveTerminalInfo()
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    /**
     * 提交设备信息
     *
     * @param context
     */
    fun saveTerminalInfo() {
        val vo = HashMap<String, Any>()
        val deviceInfo: DeviceInfo = DeviceInfo.instance
        val macAddress: String = deviceInfo.getMacAddress()
        val mac = macAddress.replace(":", "")
        vo["mac"] = mac
        vo["mac1"] = macAddress
        vo["androidid"] = deviceInfo.getAndroidId(null)
        vo["imei"] = deviceInfo.iMEI
        if (!TextUtils.isEmpty(MintsApplication.OAID)) {
            vo["oaid"] = MintsApplication.OAID
        }
        vo["os"] = "android"
        vo["model"] = deviceInfo.newModel
        vo["uuid"] = DeviceUuidFactory().deviceUuid
        vo["osversion"] = deviceInfo.oSVersion
        vo["appversion"] = deviceInfo.versionName
        vo["shumeiId"] = ShumeiManager.getInstance().getShumeiDeviceId()
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.saveTerminalInfo(vo),
                        object : BaseSubscriber<BaseResponse<Any>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                            }

                            override fun onNext(baseResponse: BaseResponse<Any>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                when (code) {
                                    200 -> getHallBaseMsg()
                                }
                            }
                        })
    }

}