package com.mints.goodmoney.ui.activitys

import android.os.Bundle
import android.text.TextUtils
import android.view.KeyEvent
import android.view.View
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.express.PreLoadExpressManager
import com.mints.goodmoney.ad.vedio.VedioAdingManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo.Companion.instance
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.VedioAdingBean
import com.mints.goodmoney.mvp.presenters.AwardPresenter
import com.mints.goodmoney.mvp.views.AwardView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.widgets.countdowntimer.CountDownTimerSupport
import com.mints.goodmoney.ui.widgets.countdowntimer.OnCountDownTimerListener
import com.mints.goodmoney.utils.SoundPoolUtil
import com.mints.goodmoney.utils.SpanUtils
import com.mints.goodmoney.utils.Utils
import com.mints.goodmoney.utils.rxutil.CommonRxTask
import com.mints.goodmoney.utils.rxutil.RxjavaUtil
import com.umeng.analytics.MobclickAgent
import kotlinx.android.synthetic.main.activity_award.*
import java.math.BigDecimal
import java.util.*

/**
 * 描述：奖励界面
 * 作者：孟崔广
 * 时间：2020/10/09 15:47
 */
class AwardActivity : BaseActivity(), AwardView, View.OnClickListener {

    private lateinit var vedioAdingManager: VedioAdingManager
    private val awardPresenter by lazy { AwardPresenter() }
    private var mTimer: CountDownTimerSupport? = null
    private var curCoin = 0 //传入金币
    private var extraId = ""//传入key
    private var carrierType = ""//传入载体
    private var loadVedioFailCount = 0 // 视频失败次数

    override fun getContentViewLayoutID() = R.layout.activity_award

    override fun isApplyKitKatTranslucency() = false

    override fun toggleOverridePendingTransition() = true

    override fun getOverridePendingTransitionMode() = TransitionMode.SCALE

    override fun initViewsAndEvents() {
        awardPresenter.attachView(this)

        vedioAdingManager = VedioAdingManager.getInstance(this)

        if (!AppConfig.app_black_flag) {
            // 首次进行黑名单校验
            judgeAppInfo()
        } else {
            pushAward()
        }

        initExpress()
        initListener()
        initDataView()
    }

    /**
     * 校验是否属于黑名单
     */
    private fun judgeAppInfo() {
        val deviceInfo = instance
        RxjavaUtil.executeRxTask<String>(object : CommonRxTask<String?>("") {
            override fun doInIOThread() {
                var result = "false"

                val serverBlackName = AppConfig.app_black_name
                val serverBlackPkg = AppConfig.app_black_pkg

                // 校验应用名称
                if (!TextUtils.isEmpty(serverBlackName)) {
                    val sysNameList = deviceInfo.getAppNameInfoList()
                    if (sysNameList != null && sysNameList.size > 0) {
                        val serverBlackNameList = serverBlackName.split(",")
                        for (serverBlackName in serverBlackNameList) {
                            if (TextUtils.equals(result, "true")) {
                                break
                            }
                            for (sysName in sysNameList) {
                                // 系统名称 包含 服务名称
                                if (sysName.contains(serverBlackName)) {
                                    result = "true"
                                    break
                                }
                            }
                        }
                    }
                }

                // 校验应用包名
                if (TextUtils.equals(result, "false") && !TextUtils.isEmpty(serverBlackPkg)) {
                    val sysPkgList = deviceInfo.getAppPkgInfoList()
                    if (sysPkgList != null && sysPkgList.size > 0) {
                        val serverBlackPkgList = serverBlackPkg.split(",")
                        for (serverBlackPkg in serverBlackPkgList) {
                            if (TextUtils.equals(result, "true")) {
                                break
                            }
                            for (sysPkgName in sysPkgList) {
                                // 系统名称 包含 服务名称
                                if (sysPkgName.contains(serverBlackPkg)) {
                                    result = "true"
                                    break
                                }
                            }
                        }
                    }
                }

                t = result
            }

            override fun doInUIThread() {
                if (TextUtils.equals(t.toString(), "true")) {
                    // 黑名单
                    awardPresenter.saveTerminalInfo()
                    carrierType = Constant.CARRIER_BLACK
                }
                AppConfig.app_black_flag = true
                pushAward()
            }
        })
    }

    private fun initDataView() {
        // 金币声音
        try {
            SoundPoolUtil.getInstance().getGoldVoice()
        } catch (e: Exception) {
            e.printStackTrace()
        }
        // 获取按键栏
        Utils.hideBottomUIMenu(this)
        // 开启3秒倒计时
        startTime()
        pushUmengEvent()
    }

    /**
     * 发放奖励
     */
    private fun pushAward() {
        when (carrierType) {
            Constant.CARRIER_HOMEVEDIO_CHALLENGE, Constant.CARRIER_MINIVEDIO_CHALLENGE,
            Constant.CARRIER_GAME_ONLINE, Constant.CARRIER_EATMEAL,
            Constant.CARRIER_RUISHINEWS_CHALLANGE, Constant.CARRIER_ZHANGYUE_CHALLENGE,
            Constant.CARRIER_XMLY_CHALLENGE, Constant.CARRIER_SHARE_NEWS -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("我知道了")
            }
            Constant.CARRIER_BLESSINGBAG -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("看视频再领${extraId}金币")

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_BLESSINGBAG_DOUBLE
            }
            Constant.CARRIER_HOMEVEDIO -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("看视频再领${extraId}金币")

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_HOMEVEDIO_DOUBLE
            }
            Constant.CARRIER_RUISHINEWS -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("看视频再领${extraId}金币")

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_RUISHINEWS_DOUBLE
            }
            Constant.CARRIER_SMALLHOMEVEDIO -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("看视频再领${extraId}金币")

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_SMALLHOMEVEDIO_DOUBLE
            }
            Constant.CHALLENGE_SHAREFRIEND -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("看视频再领${extraId}金币")

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_CHALLENGE_SHAREFRIEND_DOUBLE
            }
            Constant.CARRIER_NEW_USER -> {
                tvAwardContent.setText("新人红包")
                tvAwardNext.setText("我知道了")
                tvAwardHint.setVisibility(View.VISIBLE)
                tvAwardHint.setText("${curCoin}金币已到账")
            }
            Constant.CARRIER_NEW_VISITOR -> {
                tvAwardContent.setText("新人红包")
                tvAwardNext.setText("点击领取")
                tvAwardHint.setVisibility(View.VISIBLE)
                tvAwardHint.setText("${curCoin}金币已到账")
            }
            Constant.CARRIER_OFFLINE_DOUBLE -> {
                tvAwardContent.setText("离线收益奖励${curCoin}金币")
                tvAwardNext.setText("金币翻倍")
            }
            Constant.CARRIER_ZHANGYUE -> {
                tvAwardContent.setText("阅读奖励${curCoin}金币")
                tvAwardNext.setText("领取金币")
            }
            Constant.CARRIER_SIGNIN_HOMEPAGE_AWARD -> {
                tvAwardContent.setText("签到奖励${curCoin}金币")
                tvAwardNext.setText("看视频最高可得3倍金币奖励")

                carrierType = Constant.CARRIER_SIGNIN_HOMEPAGE_CARD
            }
            Constant.CARRIER_EATMEAL_SUBSIDY_NOT -> {
                tvAwardContent.setText("还未到吃饭时间")
                tvAwardNext.setText("我知道了")
            }
            Constant.CARRIER_GAME -> {
                if (curCoin > 0) {
                    tvAwardContent.setText("游戏奖励${curCoin}金币")
                } else {
                    tvAwardContent.setText("很遗憾,游戏试玩不足3秒")
                }
                tvAwardNext.setText("我知道了")
            }
            Constant.CARRIER_HIGH_ACTIVITY, Constant.CARRIER_CPD -> {
                if (curCoin > 0) {
                    tvAwardContent.setText("试玩奖励${curCoin}金币")
                    tvAwardNext.setText("领取金币")
                    val vo = HashMap<String, Any>()
                    vo["carrierType"] = carrierType
                    awardPresenter.reportAddCoinMsg(vo)
                } else {
                    tvAwardContent.setText("很遗憾,试玩时间不足")
                    tvAwardNext.setText("我知道了")
                }
            }
            Constant.CARRIER_SIGNIN_HOMEPAGE_CARD -> {
                tvAwardContent.text = "奖励金币已发放"
                tvAwardNext.visibility = View.GONE
                tvAwardHint.visibility = View.GONE
            }
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD,
            Constant.CARRIER_WALK_BUBBLE, Constant.CARRIER_EATMEAL_SUBSIDY,
            Constant.CARRIER_WALK, Constant.CARRIER_HOMEWATER -> {
                tvAwardContent.setText("+${curCoin}金币")
                tvAwardNext.setText("看视频领取")
            }
            else -> {
                tvAwardContent.setText("${curCoin}金币已到账")
                tvAwardNext.setText("领取金币")
            }
        }
    }

    /**
     * 推送umeng事件埋点
     */
    private fun pushUmengEvent() {
        if (!TextUtils.isEmpty(carrierType) && curCoin > 0) {
            // 埋点上送事件
            val map = mutableMapOf<String, String>()
            map["userId"] = UserManager.getInstance().userID
            map["coin"] = "" + curCoin
            MobclickAgent.onEvent(this, carrierType, map)
        }
    }

    override fun finish() {
        super.finish()
        //关闭窗体动画显示
        overridePendingTransition(0, R.anim.scale_out)
    }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            curCoin = it.getInt(Constant.MAIN_CUR_COIN, 0)
            extraId = it.getString(Constant.MAIN_EXTRA_ID, "")
            carrierType = it.getString(Constant.MAIN_CARRIER_TYPE, "")
        }
    }

    override fun onResume() {
        super.onResume()

        MobclickAgent.onPageStart(this::class.java.simpleName)
        MobclickAgent.onResume(this)

        awardPresenter.getCoinMsg()
    }

    override fun onPause() {
        super.onPause()

        MobclickAgent.onPageEnd(this::class.java.simpleName)
        MobclickAgent.onPause(this)
    }

    override fun onDestroy() {
        super.onDestroy()

        mTimer?.stop()
        mTimer = null

        try {
            PreLoadExpressManager.loadADFrameLayout()
        } catch (e: java.lang.Exception) {
            e.printStackTrace()
        }

        SoundPoolUtil.getInstance().onDestory()
        PreLoadExpressManager.onDestroy()

        flAwardAd?.removeAllViews()
        vedioAdingManager.setVedioAdingListener(null)
        vedioAdingManager.onDestory()

        awardPresenter.detachView()
    }

    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        return if (keyCode == KeyEvent.KEYCODE_BACK) {
            true
        } else super.onKeyDown(keyCode, event)
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.ivAwardBack -> {
                finish()
            }
            R.id.tvAwardNext -> {
                when (carrierType) {
                    // 只有看视频才能领金币
                    Constant.CARRIER_OFFLINE_DOUBLE, Constant.CARRIER_SIGNIN_HOMEPAGE_CARD,
                    Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD,
                    Constant.CARRIER_WALK_BUBBLE, Constant.CARRIER_EATMEAL_SUBSIDY,
                    Constant.CARRIER_WALK, Constant.CARRIER_HOMEWATER -> {
                        awardVedio()
                    }
                    Constant.CARRIER_BLESSINGBAG_DOUBLE, Constant.CARRIER_CHALLENGE_SHAREFRIEND_DOUBLE,
                    Constant.CARRIER_HOMEVEDIO_DOUBLE, Constant.CARRIER_SMALLHOMEVEDIO_DOUBLE, Constant.CARRIER_RUISHINEWS_DOUBLE -> {
                        pushUmengEvent()
                        awardVedio()
                    }
                    Constant.CARRIER_NEW_VISITOR -> {
                        readyGoThenKill(WxLoginActivity::class.java)
                    }
                    else -> {
                        finish()
                    }
                }
            }
        }
    }

    /**
     * 获取激励视频
     */
    private fun awardVedio() {
        if (vedioAdingManager.getVedioFinishFlag()) {
            showToast("今日视频已看完，请明天再来吧")
            return
        }

        showLoading("加载中...")

        val bean = VedioAdingBean()
        bean.setCarrierType(carrierType)
        bean.setCurCoin(curCoin)
        bean.setExtraId(extraId)

        loadVedio(vedioAdingManager, bean, true)
    }

    /**
     * 加载激励视频
     */
    private fun loadVedio(vedioAdingManager: VedioAdingManager, bean: VedioAdingBean, isFirstLoad: Boolean) {
        vedioAdingManager.setVedioAdingListener(object : VedioAdingManager.VedioAdingListener {
            override fun vedioAdingListenerError(adType: String) {
                showToast("加载超时，请休息一下")
                hideLoading()
            }

            override fun vedioAdingListenerFail(adType: String) {
                loadVedioFailCount++
                if (loadVedioFailCount >= 2) {
                    hideLoading()
                    showToast("加载失败，请稍后重试!")
                } else {
                    loadVedio(vedioAdingManager, bean, false)
                }
            }

            override fun vedioAdingListenerSuccess(adType: String) {
                hideLoading()
                vedioAdingSuccess(adType)
            }
        })
        if (isFirstLoad) {
            // 首页按权重加载
            vedioAdingManager.loadAding(this, bean)
        } else {
            // 失败按优先级加载
            vedioAdingManager.loadFailAding(this, bean)
        }
    }


    private fun initListener() {
        tvAwardNext.setOnClickListener(this)
        ivAwardBack.setOnClickListener(this)
    }

    /**
     * 弹窗倒计时
     */
    private fun startTime() {
        mTimer = CountDownTimerSupport(3000L, 1000L)
        mTimer?.setOnCountDownTimerListener(object : OnCountDownTimerListener {
            override fun onTick(millisUntilFinished: Long) {
                if (!this@AwardActivity.isFinishing) {
                    tvAwardBack?.setText("${millisUntilFinished / 1000}")
                }
            }

            override fun onFinish() {
                if (!this@AwardActivity.isFinishing) {
                    ivAwardBack?.setVisibility(View.VISIBLE)
                    tvAwardBack?.setVisibility(View.GONE)
                }
            }
        })
        mTimer?.start()
    }


    override fun getUserTaskMsgSuc(coin: Int, riskFlag: Boolean) {
        val sumCoin = coin.toString()
        val allcoinBig = BigDecimal(sumCoin)
        val rateBig = BigDecimal("10000")
        val cashStr = allcoinBig.divide(rateBig).setScale(2, BigDecimal.ROUND_DOWN).toString()

        tvAwardCash.setText(
                SpanUtils()
                        .append("我的金币").setFontSize(40).setForegroundColor(resources.getColor(R.color.color_333))
                        .append(sumCoin).setFontSize(40).setForegroundColor(resources.getColor(R.color.color_FF9837))
                        .append("≈").setFontSize(40).setForegroundColor(resources.getColor(R.color.color_333))
                        .append("" + cashStr).setFontSize(40).setForegroundColor(resources.getColor(R.color.color_FF9837))
                        .append("元").setFontSize(40).setForegroundColor(resources.getColor(R.color.color_333))
                        .create()
        )

        // 上传风控信息
        if (riskFlag) {
            awardPresenter.riskinfo()
        }
    }

    /**
     * 随机广告完成回调
     */
    private fun setAdFinshLayout() {
        if (!isFinishing) {
            tvAwardContent.text = "奖励金币已发放"
            tvAwardNext.visibility = View.GONE
            tvAwardHint.visibility = View.GONE
        }
    }

    /**
     * 广告返回结果
     */
    private fun vedioAdingSuccess(adType: String) {
        setAdFinshLayout()
    }

    private fun initExpress() {
        try {
            if (flAwardAd != null) {
                flAwardAd.removeAllViews()
                flAwardAd.addView(PreLoadExpressManager.getADFrameLayout())
            }
        } catch (e: Exception) {

        }
    }
}