package com.mints.goodmoney.ui.activitys

import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.vedio.VedioAdingManager
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.ad.express.TTPreLoadCarrierExpressManager
import com.mints.goodmoney.manager.TtCsjAdManager
import com.mints.goodmoney.mvp.model.MorningClockBean
import com.mints.goodmoney.mvp.model.VedioAdingBean
import com.mints.goodmoney.mvp.presenters.MorningClockPresenter
import com.mints.goodmoney.mvp.views.MorningClockView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.MorningClockAdapter
import com.mints.goodmoney.utils.SpanUtils
import kotlinx.android.synthetic.main.activity_morning_clock.*

/**
 * 描述：早起打卡
 * 作者：孟崔广
 * 时间：2020/11/18 19:19
 */
class MorningClockActivity : BaseActivity()
        , View.OnClickListener, MorningClockView {

    private val morningClockPresenter by lazy { MorningClockPresenter() }
    private lateinit var morningClockAdapter: MorningClockAdapter
    private var morningClockList: MutableList<MorningClockBean.MorningClockTargetBean>? = null

    private lateinit var vedioAdingManager: VedioAdingManager
    private var loadVedioFailCount = 0
    private var morningClockBean: MorningClockBean? = null

    override fun getContentViewLayoutID() = R.layout.activity_morning_clock

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        vedioAdingManager = VedioAdingManager.getInstance(this)

        initListener()
        morningClockPresenter.attachView(this)
    }

    override fun onResume() {
        super.onResume()
        initExpress()
        morningClockPresenter.getUpEarlySignMsg()
    }

    override fun onDestroy() {
        super.onDestroy()
        flMorningClockAd?.removeAllViews()
        morningClockPresenter.detachView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.ivMorningClockBack -> finish()
            R.id.tvMorningClockClick -> {
                awardVedio()

                // 预加载信息流
                TTPreLoadCarrierExpressManager.getInstance().loadTtFrameLayout(TtCsjAdManager.TT_AD_NATIVEEXPRESS_MORNINGCLOCK)
            }
        }
    }

    override fun getUpEarlySignMsgSuc(data: MorningClockBean) {
        morningClockBean = data
        morningClockList = data.targetList

        if (data.isCanClick) {
            tvMorningClockClick.background = resources.getDrawable(R.drawable.shape_water_btn)
            tvMorningClockClick.isEnabled = true
        } else {
            tvMorningClockClick.background = resources.getDrawable(R.drawable.shape_tv_gold_none)
            tvMorningClockClick.isEnabled = false
        }
        tvMorningClockClick.text = data.buttonMsg
        tvMorningClockDay.text = SpanUtils()
                .append("打卡领金币    已连续打卡")
                .append("${data.continuityDays}").setForegroundColor(resources.getColor(R.color.color_FF9837))
                .append("天")
                .create()

        initRvView()
    }

    private fun initRvView() {
        if (morningClockList != null && morningClockList!!.size > 0) {
            val gridLayoutManager = GridLayoutManager(this, 2)
            rvMorningClock.layoutManager = gridLayoutManager
            morningClockAdapter = MorningClockAdapter(morningClockList!!)
            rvMorningClock.adapter = morningClockAdapter
        }
    }

    private fun initListener() {
        ivMorningClockBack.setOnClickListener(this)
        tvMorningClockClick.setOnClickListener(this)
    }

    /**
     * 获取激励视频
     */
    private fun awardVedio() {
        if (vedioAdingManager.vedioFinishFlag) {
            showToast("今日视频已看完，请明天再来吧")
            return
        }

        showLoading("加载中...")

        val bean = VedioAdingBean()
        bean.carrierType = Constant.CARRIER_MORNING_CLOCK
        loadVedio(vedioAdingManager, bean, true)
    }

    /**
     * 加载激励视频
     */
    private fun loadVedio(vedioAdingManager: VedioAdingManager, bean: VedioAdingBean, isFirstLoad: Boolean) {
        vedioAdingManager.setVedioAdingListener(object : VedioAdingManager.VedioAdingListener {
            override fun vedioAdingListenerError(adType: String) {
                showToast("加载超时，请休息一下")
                hideLoading()
            }

            override fun vedioAdingListenerFail(adType: String) {
                loadVedioFailCount++
                if (loadVedioFailCount >= 2) {
                    hideLoading()
                    showToast("加载失败，请稍后重试!")
                } else {
                    loadVedio(vedioAdingManager, bean, false)
                }
            }

            override fun vedioAdingListenerSuccess(adType: String) {
                hideLoading()
                vedioAdingSuccess(adType)
            }
        })
        if (isFirstLoad) {
            // 首页按权重加载
            vedioAdingManager.loadAding(this, bean)
        } else {
            // 失败按优先级加载
            vedioAdingManager.loadFailAding(this, bean)
        }
    }

    private fun vedioAdingSuccess(adType: String) {
        try {
            if (morningClockList != null && morningClockList!!.size > 0) {
                for (morningBean in morningClockList!!) {
                    if (morningBean.needDays == morningClockBean?.continuityDays) {
                        val bundle = Bundle()
                        bundle.putInt(Constant.MAIN_CUR_COIN, morningBean.coin)
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_MORNING_CLOCK)
                        readyGo(AwardActivity::class.java, bundle)
                        break
                    }
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }

        morningClockPresenter.getUpEarlyClickButton(adType)
    }

    /**
     * 初始化信息iyc
     */
    private fun initExpress() {
        try {
            if (TTPreLoadCarrierExpressManager.getInstance().ttFrameLayout != null) {
                if (flMorningClockAd != null) {
                    flMorningClockAd.removeAllViews()
                    flMorningClockAd.addView(TTPreLoadCarrierExpressManager.getInstance().ttFrameLayout)
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}