package com.mints.goodmoney.ui.activitys

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.tz_ad.CoralDownload
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.AppTryPlayManager
import com.mints.goodmoney.manager.DownloadApkManager
import com.mints.goodmoney.mvp.model.TzTaskBean
import com.mints.goodmoney.service.AppInstallService
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.TaskAdapter
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener
import com.mints.goodmoney.ui.widgets.CustomDialogAsApple
import com.mints.goodmoney.ui.widgets.DialogListener
import com.mints.goodmoney.ui.widgets.TaskDialog
import com.mints.goodmoney.utils.AppUtil
import com.mints.goodmoney.utils.CacheUtil
import com.mints.goodmoney.utils.SpacesItemDecoration
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import com.tz.sdk.coral.ad.CoralAD
import com.tz.sdk.coral.callback.h5.DownloadProcess
import kotlinx.android.synthetic.main.activity_task.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 *
 * 描述：试玩任务
 */
class TaskActivity : BaseActivity(), OnItemClickListener, OnRefreshListener, CoralDownload.OnAdLoadListener, OnItemChildClickListener, View.OnClickListener, DownloadApkManager.OnMyDownloadListener {

    private var mTaskAdapter: TaskAdapter? = null

    private val mTaskList: MutableList<CoralAD> = arrayListOf()
    private val mFakeTaskList: MutableList<TzTaskBean> = arrayListOf()

    // 任务弹框
    private var taskDialog: TaskDialog? = null

    private lateinit var cdaa: CustomDialogAsApple

    // 天卓下载广告请求
    private var mCoralDownload: CoralDownload? = null
    private var mDownloadProcess: DownloadProcess? = null

    // APP下载回调广播
    private var mReceiverBroadcastReceiver: BroadcastReceiver? = null

    // 试完时间不足弹窗
    private var tryTimeOut = false

    companion object {
        const val TASK_COIN = "task_coin"
        const val TASK_USE_TIME = "task_use_time"
    }

    private var mCoin = 0
    private var needUseTime = 0

    override fun getBundleExtras(extras: Bundle) {
        super.getBundleExtras(extras)
        mCoin = extras.getInt(TASK_COIN)
        needUseTime = extras.getInt(TASK_USE_TIME)
    }

    override fun getContentViewLayoutID() = R.layout.activity_task

    override fun initViewsAndEvents() {
        tv_title.text = "下载试玩任务"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        mCoralDownload = CoralDownload(CoralDownload.RELEASE_TASK_TYPE).setOnAdLoadListener(this)

        initView()
        initListener()

        loadData()
    }

    private fun initView() {
        val gridLayoutManager = GridLayoutManager(this, 3)
        recy_task.layoutManager = gridLayoutManager
        recy_task.addItemDecoration(SpacesItemDecoration(3, SpacesItemDecoration.px2dp(10f)))
        mTaskAdapter = TaskAdapter(mFakeTaskList, this)
        recy_task.adapter = mTaskAdapter
        recy_task.setItemViewCacheSize(20)
        mTaskAdapter?.setOnItemClickListener(this)
        mTaskAdapter?.setOnItemChildClickListener(this)
        iv_left_icon.setOnClickListener(this)
    }

    private fun initListener() {
        srl_task.setOnRefreshListener(this)
    }

    override fun onResume() {
        super.onResume()

        DownloadApkManager.tryOnceInstallApk()

        refreshDemoTask()
    }

    /**
     * 刷新高额任务
     */
    private fun refreshDemoTask() {
        mTaskAdapter?.let {
            val position = it.getPosition()
            if (mFakeTaskList.size == 0 || tryTimeOut || mFakeTaskList[position].state == 3) return

            val currentPkgName = mFakeTaskList[position].currentPkgName

            if (currentPkgName != null) {
                if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, needUseTime)) {
                    // 完成试玩任务
                    mFakeTaskList[position].state = 2
                    it.notifyItemChanged(position)

                    // 上报激活完成
                    mDownloadProcess?.reportAppActivated()
                } else {
                    if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, 5)) {
                        tryTimeOut = true
                        // 试玩时间不足
                        mFakeTaskList[position].state = 4
                        it.notifyItemChanged(it.getPosition())

                        val bundle = Bundle()
                        bundle.putInt(Constant.MAIN_CUR_COIN, 0)
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD)
                        readyGo(AwardActivity::class.java, bundle)
                    } else {
                        // 试玩时间不足5秒
                        mFakeTaskList[position].state = 1
                        it.notifyItemChanged(it.getPosition())
                    }
                }
            }
        }
    }

    private fun loadData() {
        showLoading("加载中...")
        mCoralDownload?.pull()
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onItemClick(view: View?, position: Int) {
    }

    private fun clickDialog(position: Int) {
        taskDialog = TaskDialog(this)
        taskDialog?.setData(mTaskList[position], needUseTime, mCoin)
        taskDialog?.show()
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        loadData()
    }

    override fun onLoadSuccess(dataList: MutableList<CoralAD>?) {
        hideLoading()
        srl_task.finishRefresh()

        dataList?.let {
            mFakeTaskList.clear()
            for (coralAD in it) {
                mFakeTaskList.add(TzTaskBean(coralAD.icon, coralAD.description, mCoin, 0, null))
            }

            mTaskList.clear()
            mTaskList.addAll(it)
            mTaskAdapter?.notifyDataSetChanged()
        }
    }

    override fun onLoadFail() {
        showToast("加载失败,请下拉刷新重试")

        hideLoading()
        srl_task.finishRefresh(false)
    }

    override fun onGetDownloadProcess(downloadProcess: DownloadProcess?) {
        // 点击之后回调下载数据
        mDownloadProcess = downloadProcess

        // 跳转去下载
        val downloadUrl = downloadProcess!!.downloadUrl
        val packageName = downloadProcess.packageName
        DownloadApkManager.setOnMyDownloadListener(this)
        DownloadApkManager.downloadApk(this, downloadUrl, packageName)
    }

    override fun onDestroy() {
        mCoralDownload?.destroy()
        mDownloadProcess = null
        DownloadApkManager.destroy()
        CacheUtil.clearAllCache(context)
        if (mReceiverBroadcastReceiver != null) {
            mContext.stopService(Intent(context, AppInstallService::class.java))
            mContext.unregisterReceiver(mReceiverBroadcastReceiver)
        }

        super.onDestroy()
    }

    override fun onBackPressed() {
//        super.onBackPressed()
        backDialog()
    }

    /**
     * 注册试玩任务监听
     */
    private fun registerBroad() {
        if (mReceiverBroadcastReceiver != null) return

        mContext.startService(Intent(context, AppInstallService::class.java))

        mReceiverBroadcastReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                if (intent == null) return

                try {
                    taskDialog?.dismiss()

                    val pkg = intent.getStringExtra("pkg")
                    mTaskAdapter?.let {
                        mFakeTaskList[it.getPosition()].currentPkgName = pkg
                        mFakeTaskList[it.getPosition()].state = 1
                        it.notifyItemChanged(it.getPosition())

                        // 上报安装完成
                        mDownloadProcess?.reportInstallSuccess(false)
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }

        val intentFilter = IntentFilter()
        intentFilter.addAction(AppInstallService.APP_INSTALL_ACTION)
        mContext.registerReceiver(this.mReceiverBroadcastReceiver, intentFilter)
    }

    override fun onItemChildClick(view: View?, position: Int) {
        when (mFakeTaskList[position].state) {
            // 0 立即下载, 1 去试玩, 2 领取奖励
            0 -> {
                tryTimeOut = false
                if (AppUtil.isOpenUsageStats()) {
                    clickDialog(position)
                } else {
                    AppTryPlayManager.openAppUsageStats(this)
                }
            }
            1 -> {
                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 0
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(mContext, currentPkgName)) {

                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 0
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
            2 -> {
                val bundle = Bundle()
                bundle.putInt(Constant.MAIN_CUR_COIN, mCoin)
                bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD)
                readyGo(AwardActivity::class.java, bundle)

                // 重置当前列表状态
                mTaskAdapter?.let {
                    mFakeTaskList[it.getPosition()].state = 3
                    it.notifyItemChanged(it.getPosition())
                }
            }
            3 -> {
                showToast("当前任务已完成，试试其他任务吧！")
            }
            4 -> {
                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 0
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(mContext, currentPkgName)) {
                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 0
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
        }
    }

    private fun backDialog() {
        cdaa = CustomDialogAsApple(context, object : DialogListener() {
            override fun onClick(v: View) {
                if (cdaa.isShowing) {
                    cdaa.dismiss()
                }
                when (v.id) {
                    R.id.dialog_btn_right -> {
                        finish()
                    }
                }
            }
        })
        cdaa.setTitle("提示")
        cdaa.setContent("退出当前页面将会重置当前任务状态")
        cdaa.setLeft("取消")
        cdaa.setRight("确定")
        cdaa.show()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> {
                backDialog()
            }
        }
    }

    /**
     * 开始下载
     */
    override fun onDownloadStart() {
        taskDialog?.dismiss()
        // 上报开始下载
        mDownloadProcess?.reportDownloadStart(false)

        registerBroad()
    }

    /**
     * 下载成功
     */
    override fun onDownloadSuccess(path: String) {
        // 上报下载成功
        mDownloadProcess?.reportDownloadSuccess(path, false)
    }
}