package com.mints.goodmoney.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.mints.goodmoney.R
import com.mints.goodmoney.mvp.model.TzTaskBean
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener
import com.mints.library.utils.GlideUtils

class TaskAdapter(val dataList: List<TzTaskBean>, val context: Context) : RecyclerView.Adapter<TaskAdapter.ViewHolder>() {

    private var mCurrentPosition = 0

    lateinit var mOnItemClickListener: OnItemClickListener
    lateinit var mOnItemChildClickListener: OnItemChildClickListener

    inner class ViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val ivAvatar: ImageView = view.findViewById(R.id.item_iv_avatar)
        val tvTitle: TextView = view.findViewById(R.id.item_tv_title)
        val tvCoin: TextView = view.findViewById(R.id.item_tv_coin)

        //        val tvText: TextView = view.findViewById(R.id.item_tv_text)
        val btnSubmit: Button = view.findViewById(R.id.item_btn_submit)
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.item_task_recy, parent, false)
        return ViewHolder(view)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val data = dataList[position]

        GlideUtils.loadImageView(context, data.icon, holder.ivAvatar)
        holder.tvTitle.text = data.title
        holder.tvCoin.text = "+" + data.coin + "金币"

        when (data.state) {
            0 -> holder.btnSubmit.text = "立即下载"
            1 -> holder.btnSubmit.text = "去试玩"
            2 -> holder.btnSubmit.text = "立即领取"
            3 -> holder.btnSubmit.text = "已完成"
            4 -> holder.btnSubmit.text = "继续试玩"
        }

        //当前选中
//        if (getPosition() == position) {
//            holder.tvTitle.setTextColor(ContextCompat.getColor(context, R.color.white))
//            holder.tvCoin.setTextColor(ContextCompat.getColor(context, R.color.white))
//            holder.tvText.setTextColor(ContextCompat.getColor(context, R.color.white))
//            holder.itemView.setBackgroundResource(R.drawable.shape_vip_adapter_none)
//            holder.btnSubmit.setBackgroundResource(R.drawable.shape_my_red)
//        } else {
//        holder.tvTitle.setTextColor(ContextCompat.getColor(context, R.color.black))
//        holder.tvCoin.setTextColor(ContextCompat.getColor(context, R.color.color_FF9837))
//        holder.tvText.setTextColor(ContextCompat.getColor(context, R.color.gray))
//        holder.itemView.setBackgroundResource(R.drawable.shape_dialog_bg)
//        holder.btnSubmit.setBackgroundResource(R.drawable.shape_btn_switch)
//        }

        if (::mOnItemClickListener.isInitialized) {
            holder.itemView.setOnClickListener {
                setPosition(position)
                mOnItemClickListener.onItemClick(it, position)
            }
        }

        if (::mOnItemChildClickListener.isInitialized) {
            holder.btnSubmit.setOnClickListener {
                setPosition(position)
                mOnItemChildClickListener.onItemChildClick(it, position)
            }
        }
    }

    fun getPosition() = mCurrentPosition

    private fun setPosition(currentPosition: Int) {
        this.mCurrentPosition = currentPosition
        notifyDataSetChanged()
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

    fun setOnItemChildClickListener(listener: OnItemChildClickListener) {
        mOnItemChildClickListener = listener
    }

    override fun getItemCount() = dataList.size
}