package com.mints.goodmoney.ui.widgets

import android.app.Activity
import android.app.Dialog
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.view.WindowManager
import android.widget.TextView
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.vedio.VedioAdingManager
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.mvp.model.VedioAdingBean
import com.mints.goodmoney.utils.ToastUtil
import com.mints.library.utils.nodoubleclick.AntiShake

/**
 * 提现弹窗
 */
class DrawcashVideoDialog(activity: Activity) :
        Dialog(activity, R.style.dialog), View.OnClickListener {

    private var onClickListener: OnClickListener? = null

    private var vedioAdingManager: VedioAdingManager? = null
    private var loadVedioFailCount = 0

    private var tvContent: TextView
    private var tvNext: TextView
    private var activity: Activity? = null

    init {
        setContentView(R.layout.dialog_drawcash)
        // 设置window属性
        val lp = window!!.attributes
        lp.gravity = Gravity.CENTER
        lp.width = WindowManager.LayoutParams.MATCH_PARENT
        lp.windowAnimations = R.style.DialogAnimBottom
        window!!.attributes = lp

        vedioAdingManager = VedioAdingManager.getInstance(activity)

        findViewById<View>(R.id.btn_dialog_drawcash_back).setOnClickListener(this)
        tvContent = findViewById<View>(R.id.btn_dialog_drawcash_content) as TextView
        tvNext = findViewById<View>(R.id.btn_dialog_drawcash_next) as TextView
        tvNext.setOnClickListener(this)
        this.activity = activity
    }

    fun onDestory(){
        vedioAdingManager?.setVedioAdingListener(null)
        vedioAdingManager?.onDestory()

        activity = null
    }

    override fun onClick(v: View) {
        if (AntiShake.check(v.id)) return
        when (v.id) {
            R.id.btn_dialog_drawcash_next -> {
                if (TextUtils.equals(tvNext.text.toString(), "去提现")) {
                    onClickListener?.onClick()
                    dismiss()
                } else {
                    awardVedio()
                }
            }
            R.id.btn_dialog_drawcash_back -> {
                dismiss()
            }
        }
    }

    fun setContent(content: String) {
        tvContent.text = content
    }

    fun setBtnText(text: String) {
        tvNext.text = text
    }

    /**
     * 获取激励视频
     */
    private fun awardVedio() {
        if (activity == null) return

        loadVedioFailCount = 0
        ToastUtil.show(activity, "加载中...")

        val bean = VedioAdingBean()
        bean.carrierType = Constant.CARRIER_DRAWCASH

        vedioAdingManager?.let { loadVedio(it, bean, true) }
    }

    /**
     * 加载激励视频
     */
    private fun loadVedio(vedioAdingManager: VedioAdingManager?, bean: VedioAdingBean, isFirstLoad: Boolean) {
        if (activity == null) return
        vedioAdingManager?.let {
            it.setVedioAdingListener(object : VedioAdingManager.VedioAdingListener {
                override fun vedioAdingListenerError(adType: String) {
                    ToastUtil.show(activity, "加载超时，请休息一下")
                }

                override fun vedioAdingListenerFail(adType: String) {
                    loadVedioFailCount++
                    if (loadVedioFailCount >= 2) {
                        ToastUtil.show(activity, "加载超时，请休息一下")
                    } else {
                        loadVedio(vedioAdingManager, bean, false)
                    }
                }

                override fun vedioAdingListenerSuccess(adType: String) {
                    if (it.isVedioAdDownload) {
                        TrackManager.getInstance().drawcashVideo()
                    }
                }
            })

            if (isFirstLoad) {
                // 首页按权重加载
                it.loadAding(activity, bean)
            } else {
                // 失败按优先级加载
                it.loadFailAding(activity, bean)
            }
        }
    }

    interface OnClickListener {
        fun onClick()
    }

    fun setOnClickListener(onClickListener: OnClickListener?) {
        this.onClickListener = onClickListener
    }
}